# GenchAPI
This is the open source SDK of Shanghai JianQiao University.

## Features
- Daily iHealth Sign
> Useful features will be constantly updated

## Usage
1. You need to install GenchAPI before.
~~~shell
# MacOS
pip3 install GenchAPI
# Windows
pip install GenchAPI
~~~
2. Create a new file with following code.
~~~python
from GenchAPI import GenchAPI
GenchAPI.sign("1900001","123456")
~~~ 

## Contributors
- [missuo](https://github.com/missuo)

## License
MIT License